@@ -18,13 +18,15 @@ from groundx.model.api_key_management_list_response_api_keys_item import ApiKeyM
 from groundx.model.bucket_detail import BucketDetail
 from groundx.model.bucket_list_response import BucketListResponse
 from groundx.model.bucket_response import BucketResponse
+from groundx.model.bucket_update_detail import BucketUpdateDetail
 from groundx.model.bucket_update_request import BucketUpdateRequest
 from groundx.model.bucket_update_request_bucket import BucketUpdateRequestBucket
+from groundx.model.bucket_update_response import BucketUpdateResponse
 from groundx.model.document_delete_response import DocumentDeleteResponse
 from groundx.model.document_list_response import DocumentListResponse
 from groundx.model.document_local_upload_request import DocumentLocalUploadRequest
-from groundx.model.document_local_upload_request_blob import DocumentLocalUploadRequestBlob
-from groundx.model.document_local_upload_request_metadata import DocumentLocalUploadRequestMetadata
+from groundx.model.document_local_upload_request_item import DocumentLocalUploadRequestItem
+from groundx.model.document_local_upload_request_item_metadata import DocumentLocalUploadRequestItemMetadata
 from groundx.model.document_lookup_response import DocumentLookupResponse
 from groundx.model.document_remote_upload_request import DocumentRemoteUploadRequest
 from groundx.model.document_remote_upload_request_documents import DocumentRemoteUploadRequestDocuments
@@ -41,10 +43,6 @@ from groundx.model.process_status_response_ingest_progress_complete import Proce
 from groundx.model.process_status_response_ingest_progress_errors import ProcessStatusResponseIngestProgressErrors
 from groundx.model.process_status_response_ingest_progress_processing import ProcessStatusResponseIngestProgressProcessing
 from groundx.model.processing_status import ProcessingStatus
-from groundx.model.project_bind_bucket400_response import ProjectBindBucket400Response
-from groundx.model.project_bind_bucket_response import ProjectBindBucketResponse
-from groundx.model.project_bucket_binding import ProjectBucketBinding
-from groundx.model.project_bucket_binding_project import ProjectBucketBindingProject
 from groundx.model.project_detail import ProjectDetail
 from groundx.model.project_list_response import ProjectListResponse
 from groundx.model.project_response import ProjectResponse
